/**
 * ios SDK   =》  js调用oc
 */
class iosSDK {
    /**
     * 监听h5切到后台
     * @param func 回调函数
     * @example
                iosSDK.onHide(()=>{
                        console.log("js 切到后台");
                });
     */
    onHide(func) {
        //@ts-ignore
        window.appOnHideCallBack = func;
    }
    /**
     * 监听h5回到前台
     * @param func 回调函数
     * @example
            iosSDK.onShow(()=>{
                    console.log("js 回到前台")
            });
     */
    onShow(func) {
        //@ts-ignore
        window.appOnShowCallBack = func;
    }
    /**
     * 此方法暂时不使用（无明确需求需要去掉APP加载webview之间的白屏）
     *
     * 引擎初始化完成游戏正式开始通知APP显示H5游戏
     * 因为H5引擎初始化到游戏开始显示之间有一段黑屏时间 加上webview渲染页面前有一段白屏时间 此函数是为了让APP那边等待游戏正式登场才显示出来而使用的
     */
    tellAppToShowGame() {
        this.postMessage("showGame");
    }
    /**
     * 拉起视频广告
     * @param rewardAdCallBack 视频回调函数
     * @example
            iosSDK.showVideoAD((res)=>{
                if(res == "异常"){
                    console.log("视频拉取异常，请重新尝试");
                    return;
                }
                if(res == "YES"){
                    console.log("看完视频给奖励")
                }else{
                    console.log("没看完视频不给奖励");
                }
            })
     */
    showVideoAD(rewardAdCallBack) {
        console.log("拉起视频");
        //@ts-ignore 注册视频全局回调函数
        window.rewardAdCallBack_iosSdk = rewardAdCallBack;
        //this.postMessage("showVideoAD");
        try {
            window.videoAdFinished = function(){
                rewardAdCallBack("YES");
            };//bind(this);
            window.videoAdCancel = function(){};//bind(this);
            window.AndroidWebView.showVideoAd("r01");
            window.AndroidWebView.showSysSelfRenderLargeAd("f02");
        }catch(err){
            console.log(err);
        }
    }
    /**
     * 拉起横幅广告
     */
    showBanner() {
        console.log("展示banner");
        window.rewardAdCallBack_iosSdk = null;
        this.postMessage("showBanner");
    }
    /**
     * 隐藏横幅广告
     */
    hideBanner() {
        console.log("隐藏banner");
        window.rewardAdCallBack_iosSdk = null;
        this.postMessage("hideBanner");
    }
    /**
     * 删除横幅广告
     */
    removeBanner() {
        console.log("删除banner");
        window.rewardAdCallBack_iosSdk = null;
        this.postMessage("removeBanner");
    }
    /**
     * 拉起插屏广告
     */
    showInterstitialAD() {
        console.log("显示插屏广告");
        window.rewardAdCallBack_iosSdk = null;
        //this.postMessage("showInterstitialAD");
        try{window.AndroidWebView.showIntersAd("i01")}catch(err){};
    }
    /**
    * js调用oc
    * @param func oc中注册的监听函数名
    * @param args 参数
    */
    postMessage(func, args = null) {
        /*try {
            //@ts-ignore
            window.webkit.messageHandlers[func].postMessage(args);
        }
        catch (error) {
            console.log("ios视频错误")
            window.rewardAdCallBack_iosSdk && window.rewardAdCallBack_iosSdk("YES");
            window.rewardAdCallBack_iosSdk = null;
        }*/
    }
}
window.iosSdk =  new iosSDK();

try {
    window.AndroidWebView.showBannerAd("b01");
    window.AndroidWebView.showSysSelfRenderLargeAd("f01");
}catch(err){
    console.log(err);
}